==> spanishdelight-1.20.1-1.0.7-sources.jar: io/github/macuguita/utils/ModCustomTrades.java <==
package io.github.macuguita.utils;

import io.github.macuguita.item.ModItems;
import net.fabricmc.fabric.api.object.builder.v1.trade.TradeOfferHelper;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_1914;
import net.minecraft.class_3852;

public class ModCustomTrades {

    public static void registerCustomTrades() {
        TradeOfferHelper.registerVillagerOffers(class_3852.field_17056, 1,
                factories -> {
                    factories.add((entity, random) -> new class_1914(
                            new class_1799(class_1802.field_8687, 1),
                            new class_1799(ModItems.GREEN_BEAN, 10),
                            10, 8, 0.02F
                    ));
                });

        TradeOfferHelper.registerVillagerOffers(class_3852.field_17056, 2,
                factories -> {
                    factories.add((entity, random) -> new class_1914(
                            new class_1799(vectorwing.farmersdelight.common.registry.ModItems.TOMATO.get(), 15),
                            new class_1799(ModItems.GARLIC, 5),
                            8, 8, 0.02F
                    ));

                    factories.add((entity, random) -> new class_1914(
                            new class_1799(ModItems.SLICED_POTATO, 24),
                            new class_1799(ModItems.RED_PEPPER, 3),
                            8, 8, 0.02F
                    ));
                    
                    factories.add((entity, random) -> new class_1914(
                            new class_1799(vectorwing.farmersdelight.common.registry.ModItems.RICE.get(), 27),
                            new class_1799(ModItems.GREEN_PEPPER, 9),
                            8, 8, 0.02F
                    ));
                });

        TradeOfferHelper.registerVillagerOffers(class_3852.field_17056, 3,
                factories -> {
                    factories.add((entity, random) -> new class_1914(
                            new class_1799(ModItems.GAZPACHO, 1),
                            new class_1799(ModItems.GARLIC, 20),
                            10, 8, 0.02F
                    ));

                    factories.add((entity, random) -> new class_1914(
                            new class_1799(ModItems.BRAVA_POTATOES, 1),
                            new class_1799(ModItems.RED_PEPPER, 20),
                            10, 8, 0.02F
                    ));

                    factories.add((entity, random) -> new class_1914(
                            new class_1799(ModItems.PIL_PIL_COD, 1),
                            new class_1799(ModItems.RED_PEPPER, 20),
                            10, 8, 0.02F
                    ));
                });

        TradeOfferHelper.registerVillagerOffers(class_3852.field_17056, 4,
                factories -> {
                    factories.add((entity, random) -> new class_1914(
                            new class_1799(class_1802.field_8687, 1),
                            new class_1799(ModItems.GARLIC, 34),
                            6, 10, 0.15F
                    ));

                    factories.add((entity, random) -> new class_1914(
                            new class_1799(class_1802.field_8687, 1),
                            new class_1799(ModItems.RED_PEPPER, 34),
                            6, 10, 0.15F
                    ));

                    factories.add((entity, random) -> new class_1914(
                            new class_1799(class_1802.field_8687, 1),
                            new class_1799(ModItems.GREEN_PEPPER, 34),
                            6, 10, 0.15F
                    ));
                });

        TradeOfferHelper.registerVillagerOffers(class_3852.field_17056, 5,
                factories -> {
                    factories.add((entity, random) -> new class_1914(
                            new class_1799(class_1802.field_8687, 6),
                            new class_1799(ModItems.GARLIC, 64),
                            1, 15, 0.02F
                    ));

                    factories.add((entity, random) -> new class_1914(
                            new class_1799(class_1802.field_8687, 6),
                            new class_1799(ModItems.RED_PEPPER, 64),
                            1, 15, 0.02F
                    ));

                    factories.add((entity, random) -> new class_1914(
                            new class_1799(class_1802.field_8687, 6),
                            new class_1799(ModItems.GREEN_PEPPER, 64),
                            1, 15, 0.02F
                    ));
                });


        TradeOfferHelper.registerWanderingTraderOffers(1,
                factories -> {
                    factories.add((entity, random) -> new class_1914(
                            new class_1799(ModItems.GREEN_BEAN, 32),
                            new class_1799(ModItems.GARLIC, 5),
                            10, 12, 0.1F
                    ));

                    factories.add((entity, random) -> new class_1914(
                            new class_1799(ModItems.GREEN_BEAN, 32),
                            new class_1799(ModItems.RED_PEPPER, 5),
                            10, 12, 0.1F
                    ));

                    factories.add((entity, random) -> new class_1914(
                            new class_1799(ModItems.GREEN_BEAN, 32),
                            new class_1799(ModItems.GREEN_PEPPER, 5),
                            10, 12, 0.1F
                    ));
                });

        TradeOfferHelper.registerWanderingTraderOffers(2,
                factories -> {
                    factories.add((entity, random) -> new class_1914(
                            new class_1799(ModItems.GARLIC, 64),
                            new class_1799(vectorwing.farmersdelight.common.registry.ModItems.DIAMOND_KNIFE.get(), 1),
                            1, 12, 0.15F
                    ));

                    factories.add((entity, random) -> new class_1914(
                            new class_1799(ModItems.RED_PEPPER, 64),
                            new class_1799(vectorwing.farmersdelight.common.registry.ModItems.DIAMOND_KNIFE.get(), 1),
                            1, 12, 0.15F
                    ));

                    factories.add((entity, random) -> new class_1914(
                            new class_1799(ModItems.GREEN_PEPPER, 64),
                            new class_1799(vectorwing.farmersdelight.common.registry.ModItems.DIAMOND_KNIFE.get(), 1),
                            1, 12, 0.15F
                    ));
                });


    }
}

==> spanishdelight-1.21.10-1.0.7-sources.jar: io/github/macuguita/utils/ModCustomTrades.java <==
package io.github.macuguita.utils;

import io.github.macuguita.item.ModItems;
import net.fabricmc.fabric.api.object.builder.v1.trade.TradeOfferHelper;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_1914;
import net.minecraft.class_3852;
import net.minecraft.class_9306;

public class ModCustomTrades {

    public static void registerCustomTrades() {
        TradeOfferHelper.registerVillagerOffers(class_3852.field_17056, 1,
                factories -> {
                    factories.add((entity, random) -> new class_1914(
                            new class_9306(class_1802.field_8687, 1),
                            new class_1799(ModItems.GREEN_BEAN, 10),
                            10, 8, 0.02F
                    ));
                });

        TradeOfferHelper.registerVillagerOffers(class_3852.field_17056, 2,
                factories -> {
                    factories.add((entity, random) -> new class_1914(
                            new class_9306(vectorwing.farmersdelight.common.registry.ModItems.TOMATO.get(), 15),
                            new class_1799(ModItems.GARLIC, 5),
                            8, 8, 0.02F
                    ));

                    factories.add((entity, random) -> new class_1914(
                            new class_9306(ModItems.SLICED_POTATO, 24),
                            new class_1799(ModItems.RED_PEPPER, 3),
                            8, 8, 0.02F
                    ));

                    factories.add((entity, random) -> new class_1914(
                            new class_9306(vectorwing.farmersdelight.common.registry.ModItems.RICE.get(), 27),
                            new class_1799(ModItems.GREEN_PEPPER, 9),
                            8, 8, 0.02F
                    ));
                });

        TradeOfferHelper.registerVillagerOffers(class_3852.field_17056, 3,
                factories -> {
                    factories.add((entity, random) -> new class_1914(
                            new class_9306(ModItems.GAZPACHO, 1),
                            new class_1799(ModItems.GARLIC, 20),
                            10, 8, 0.02F
                    ));

                    factories.add((entity, random) -> new class_1914(
                            new class_9306(ModItems.BRAVA_POTATOES, 1),
                            new class_1799(ModItems.RED_PEPPER, 20),
                            10, 8, 0.02F
                    ));

                    factories.add((entity, random) -> new class_1914(
                            new class_9306(ModItems.PIL_PIL_COD, 1),
                            new class_1799(ModItems.RED_PEPPER, 20),
                            10, 8, 0.02F
                    ));
                });

        TradeOfferHelper.registerVillagerOffers(class_3852.field_17056, 4,
                factories -> {
                    factories.add((entity, random) -> new class_1914(
                            new class_9306(class_1802.field_8687, 1),
                            new class_1799(ModItems.GARLIC, 34),
                            6, 10, 0.15F
                    ));

                    factories.add((entity, random) -> new class_1914(
                            new class_9306(class_1802.field_8687, 1),
                            new class_1799(ModItems.RED_PEPPER, 34),
                            6, 10, 0.15F
                    ));

                    factories.add((entity, random) -> new class_1914(
                            new class_9306(class_1802.field_8687, 1),
                            new class_1799(ModItems.GREEN_PEPPER, 34),
                            6, 10, 0.15F
                    ));
                });

        TradeOfferHelper.registerVillagerOffers(class_3852.field_17056, 5,
                factories -> {
                    factories.add((entity, random) -> new class_1914(
                            new class_9306(class_1802.field_8687, 6),
                            new class_1799(ModItems.GARLIC, 64),
                            1, 15, 0.02F
                    ));

                    factories.add((entity, random) -> new class_1914(
                            new class_9306(class_1802.field_8687, 6),
                            new class_1799(ModItems.RED_PEPPER, 64),
                            1, 15, 0.02F
                    ));

                    factories.add((entity, random) -> new class_1914(
                            new class_9306(class_1802.field_8687, 6),
                            new class_1799(ModItems.GREEN_PEPPER, 64),
                            1, 15, 0.02F
                    ));
                });


        TradeOfferHelper.registerWanderingTraderOffers(builder -> {
            builder.addOffersToPool(TradeOfferHelper.WanderingTraderOffersBuilder.SELL_COMMON_ITEMS_POOL,
                    (entity, random) -> new class_1914(
                            new class_9306(ModItems.GARLIC, 64),
                            new class_1799(vectorwing.farmersdelight.common.registry.ModItems.DIAMOND_KNIFE.get(), 1),
                            1, 12, 0.15F
                    ),
                    (entity, random) -> new class_1914(
                            new class_9306(ModItems.RED_PEPPER, 64),
                            new class_1799(vectorwing.farmersdelight.common.registry.ModItems.DIAMOND_KNIFE.get(), 1),
                            1, 12, 0.15F
                    ),
                    (entity, random) -> new class_1914(
                            new class_9306(ModItems.GREEN_PEPPER, 64),
                            new class_1799(vectorwing.farmersdelight.common.registry.ModItems.DIAMOND_KNIFE.get(), 1),
                            1, 12, 0.15F
                    )
            );
        });
    }
}
